'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.globCopy = exports.recreateDir = exports.exists = exports.glob = exports.copy = exports.touch = exports.writeJSON = exports.readJSON = exports.readFile = exports.readdir = exports.writeFile = exports.move = exports.mkdir = exports.rm = exports.fs = exports._ = exports.p = exports.path = exports.emitter = exports.promisify = exports.handleError = exports.logError = exports.log = exports.replace = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

let globCopy = exports.globCopy = function () {
  var ref = _asyncToGenerator(function* (pattern, dest) {
    let opts = arguments.length <= 2 || arguments[2] === undefined ? {} : arguments[2];

    const srcs = yield glob(pattern, _extends({ dot: false, nodir: true }, opts));
    yield Promise.all(srcs.map(function (f) {
      return _copy(p(opts.cwd || '', f), p(dest, f));
    }));
  });

  return function globCopy(_x2, _x3, _x4) {
    return ref.apply(this, arguments);
  };
}();

exports.sanitize = sanitize;
exports.vinyl = vinyl;
exports.debounce = debounce;

var _sbPromisify = require('sb-promisify');

var _sbPromisify2 = _interopRequireDefault(_sbPromisify);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _globby = require('globby');

var _globby2 = _interopRequireDefault(_globby);

var _readdirp = require('readdirp');

var _readdirp2 = _interopRequireDefault(_readdirp);

var _path2 = require('path');

var _path3 = _interopRequireDefault(_path2);

var _replace2 = require('replace');

var _replace3 = _interopRequireDefault(_replace2);

var _fsExtra = require('fs-extra');

var _fsExtra2 = _interopRequireDefault(_fsExtra);

var _log2 = require('./log');

var _log3 = _interopRequireDefault(_log2);

var _handleError2 = require('./handleError');

var _handleError3 = _interopRequireDefault(_handleError2);

var _logError2 = require('./logError');

var _logError3 = _interopRequireDefault(_logError2);

var _sbEventKit = require('sb-event-kit');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { return step("next", value); }, function (err) { return step("throw", err); }); } } return step("next"); }); }; }

// helpers
const replace = exports.replace = _replace3.default;
const log = exports.log = _log3.default;
const logError = exports.logError = _logError3.default;
const handleError = exports.handleError = _handleError3.default;
const promisify = exports.promisify = _sbPromisify2.default;
const emitter = exports.emitter = new _sbEventKit.Emitter();
const path = exports.path = _path3.default;
const p = exports.p = _path3.default.join;
const _ = exports._ = _lodash2.default;

// files
const fs = exports.fs = _fsExtra2.default;
const rm = exports.rm = promisify(fs.remove);
const mkdir = exports.mkdir = promisify(fs.mkdirs);
const move = exports.move = promisify(fs.move);
const writeFile = exports.writeFile = promisify(fs.writeFile);
const _readdir = promisify(_readdirp2.default);
const readdir = exports.readdir = function readdir(dir) {
  let opts = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
  return _readdir(Object.assign({ root: dir }, opts)).then(res => res.files);
};
const readFilePromise = promisify(fs.readFile);
const readFile = exports.readFile = file => readFilePromise(file, 'utf-8');
const readJSON = exports.readJSON = file => readFile(file).then(res => JSON.parse(res));
const writeJSON = exports.writeJSON = (path, str) => writeFile(path, JSON.stringify(str));
const touch = exports.touch = promisify(fs.ensureFile);
const copy = exports.copy = promisify(fs.copy);
const glob = exports.glob = _globby2.default;
const exists = exports.exists = where => new Promise((res, rej) => fs.stat(where, err => res(!err)));
// TODO use promises
const recreateDir = exports.recreateDir = dir => new Promise((res, rej) => {
  fs.remove(dir, err => {
    if (err) return rej(err);
    fs.mkdirs(dir, err => {
      if (err) return rej(err);
      res(dir);
    });
  });
});

function sanitize(str) {
  return str.replace(/[^a-zA-Z]/, '');
}

function vinyl(basePath, path, contents) {
  const cwd = '/';
  const base = basePath + '/';
  return { cwd, base, path, contents };
}

let debouncers = {};
function debounce(key, time, cb) {
  if (debouncers[key]) clearTimeout(debouncers[key]);
  debouncers[key] = setTimeout(cb, time);
}
//# sourceMappingURL=fns.js.map